const width = 960;
const height = 500;
const margin = { top: 20, right: 50, bottom: 65, left: 90 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;
const horizontalTicks = 8

d3.select('#container')
  .attr('height', height)
  .attr('width', width);

const body = d3.select('#body');
const csvUrl =
  'https://gist.githubusercontent.com/rohame/c66da4d5fb31f35bf2a02d6417a38f64/raw/combined_logan_data.csv';

let data = [];
const loadData = () => {
  return Promise.all([d3.csv(csvUrl)]).then(datasets => {
    data = datasets[0];
    return data;
  });
};

function showData() {
  data = data.map(d => {
    d.DATE = d.DATE.slice(0, -3);
    return {
      date: new Date(d.DATE),
      TMAX: +d.TMAX,
      PRCP: +d.PRCP,
      DEP_DELAY: +d.DEP_DELAY,
      year: d.YEAR
    };
  });

  let leftScale = d3
    .scaleLinear()
    .domain(d3.extent(data, d => d.TMAX))
    .range([innerHeight, 0]);

  let rightScale = d3
    .scaleLinear()
    .domain(d3.extent(data, d => d.DEP_DELAY))
    .range([innerHeight, 0]);

  let xScale = d3
    .scaleTime()
    .domain(d3.extent(data, d => d.date))
    .range([0, innerWidth]);

  const xAxis = d3
    .axisBottom(xScale)
    .tickFormat(d3.timeFormat('%b'))
    .tickSize(-innerHeight);
  const leftAxis = d3.axisLeft(leftScale).tickSize(-innerWidth).ticks(horizontalTicks);
  const rightAxis = d3.axisRight(rightScale).ticks(horizontalTicks);

  body
    .append('g')
    .call(leftAxis)
    .selectAll('.domain')
    .remove();

  body
    .append('g')
    .call(rightAxis)
    .attr('transform', 'translate(' + innerWidth + ',0)')
    .selectAll('.domain')
    .remove();

  body
    .append('g')
    .attr('transform', 'translate(0,' + innerHeight + ')')
    .call(xAxis)
    .selectAll('.domain')
    .remove();

  let cScale = d3
    .scaleLinear()
    .domain(d3.extent(data, d => d.PRCP))
    .range([0, 1]);

  let colorMap = d3.interpolateRgb(d3.rgb('#55ffff'), d3.rgb('#3399ff'));

  let weatherContainer = body.append('g').attr('id', 'weather-data');
  weatherContainer
    .selectAll('.dot')
    .data(data)
    .enter()
    .append('circle')
    .attr('r', 3.5)
    .attr('cx', d => xScale(d.date))
    .attr('cy', d => leftScale(d.TMAX))
    .attr('fill', d => {
      return d.PRCP < 0.1 ? 'rgba(224,224,224,0.4)' : colorMap(cScale(d.PRCP));
    });

  let delayline = d3
    .line()
    .x(d => xScale(d.date))
    .y(d => rightScale(d.DEP_DELAY));
  let aviationContainer = body.append('path');
  aviationContainer
    .datum(data)
    .attr('d', delayline)
    .attr('fill', 'none')
    .attr('stroke', 'yellow');
}

loadData().then(showData);